R/splitTypeRdata_class.R
SplitTypeRdata-class.RdAn S4 class to represent the splitTypeR data
signaturesNULL or a list of the genes
for each signature. The list should be have one entry per signature.
Default: NULL.
gsvaResultsNULL or a numeric matrix with
the sample GSVA results for each signature. The matrix should be
have one row per signature.
Default: NULL.
permutationsNULL or a list of the permutations results
for each signature. The list should be have one entry per signature.
Default: NULL.
standardDeviationNULL or a list of the sample standard
deviation for each signature. The list should be have one entry
per signature.
Default: NULL.
upscalingNULL or a list of the upscaling data
for each signature. The list should be have one entry per signature.
Default: NULL.
modelNULL or a list of the mixture models calculated
for each signature. The list should be have one entry per signature.
Default: NULL.
classificationNULL or a list of the classification for
each signature. The list should be have one entry per signature.
Default: NULL.