SplitTypeRdata objectR/splitTypeRdata_class.R
signatures-set-SplitTypeRdata-method.RdA function for replacement of the signatures slot in a
SplitTypeRdata class.
# S4 method for class 'SplitTypeRdata'
signatures(x) <- valuethe modified SplitTypeRdata object when the new value is
valid.
## Create a SplitTypeRdata object
paramDemo <- new("SplitTypeRdata")
## Demo study data frame
signaDemo <- list("SignatureA"=c("KRAS", "AKT1", "MTOR"),
"SignatureB"=c("PIK3CB", "CTTN"))
## Assign the new list to the signatures slot in the object
signatures(paramDemo) <- signaDemo